@@ -8,13 +8,11 @@
 #' @family Prediction
 #' @export
 #' @examples
-#' if (requireNamespace("rpart", quietly = TRUE)) {
 #' library(mlr3)
 #' task = tsk("rats")
-#' learner = mlr_learners$get("surv.rpart")
+#' learner = lrn("surv.kaplan")
 #' p = learner$train(task, row_ids = 1:20)$predict(task, row_ids = 21:30)
 #' head(as.data.table(p))
-#' }
 PredictionSurv = R6Class("PredictionSurv",
   inherit = Prediction,
   public = list(
@@ -35,10 +33,13 @@ PredictionSurv = R6Class("PredictionSurv",
     #'   observation in the test set. For a pair of continuous ranks, a higher rank indicates that
     #'   the observation is more likely to experience the event.
     #'
-    #' @param distr ([VectorDistribution][distr6::VectorDistribution])\cr
-    #'   [VectorDistribution][distr6::VectorDistribution] from \CRANpkg{distr6}.
-    #'   Each individual distribution in the vector represents the random variable 'survival time'
-    #'   for an individual observation.
+    #' @param distr (`matrix()|[distr6::VectorDistribution]`)\cr
+    #'   Either a matrix of predicted survival probabilities or a [distr6::VectorDistribution].
+    #'   If a matrix then column names must be given and correspond to survival times.
+    #'   Rows of matrix correspond to individual predictions. It is advised that the
+    #'   first column should be time `0` with all entries `1` and the last
+    #'   with all entries `0`. If a `VectorDistribution` then each distribution in the vector
+    #'   should correspond to a predicted survival distribution.
     #'
     #' @param lp (`numeric()`)\cr
     #'   Numeric vector of linear predictor scores. One element for each observation in the test
@@ -54,7 +55,13 @@ PredictionSurv = R6Class("PredictionSurv",
     initialize = function(task = NULL, row_ids = task$row_ids, truth = task$truth(), crank = NULL,
       distr = NULL, lp = NULL, response = NULL, check = TRUE) {
 
-      pdata = list(row_ids = row_ids, truth = truth, crank = crank, distr = distr, lp = lp, response = response)
+      if (inherits(distr, "Distribution")) {
+        # coerce to matrix if possible
+        distr <- private$.simplify_distr(distr)
+      }
+
+      pdata = list(row_ids = row_ids, truth = truth, crank = crank, distr = distr, lp = lp,
+                   response = response)
       pdata = discard(pdata, is.null)
       class(pdata) = c("PredictionDataSurv", "PredictionData")
 
@@ -83,9 +90,9 @@ PredictionSurv = R6Class("PredictionSurv",
     },
 
     #' @field distr ([VectorDistribution][distr6::VectorDistribution])\cr
-    #' Access the stored predicted survival distribution.
+    #' Convert the stored survival matrix to a survival distribution.
     distr = function() {
-      self$data$distr %??% NA_real_
+      private$.distrify_survmatrix(self$data$distr %??% NA_real_)
     },
 
     #' @field lp (`numeric()`)\cr
@@ -102,18 +109,63 @@ PredictionSurv = R6Class("PredictionSurv",
   ),
 
   private = list(
-    .censtype = NULL
+    .censtype = NULL,
+    .distr = function() self$data$distr %??% NA_real_,
+    .simplify_distr = function(x) {
+      if (!inherits(x, "VectorDistribution")) {
+        stop("'x' is not a 'VectorDistribution'")
+      }
+
+      ## check all distributions equal - return x if not
+      if (x$distlist) {
+        return(x)
+      }
+
+      ## check all distributions are WeightedDiscrete - return x if not
+      if (all(x$modelTable$Distribution != "WeightedDiscrete")) {
+        return(x)
+      }
+
+      times = x$getParameterValue("x")
+      time1 = times[[1]]
+
+      ## check all times equal - return x if not
+      if (!all(vapply(times, identical, logical(1), y = time1))) {
+        return(x)
+      }
+
+      surv <- 1 - do.call(rbind, x$getParameterValue("cdf"))
+      rownames(surv) <- NULL
+      surv
+    },
+    .distrify_survmatrix = function(x) {
+
+      if (inherits(x, "Distribution")) {
+        return(x)
+      }
+
+      assert(all(x[, 1] == 1))
+      assert(all(x[, ncol(x)] == 0))
+
+      distr6::as.Distribution(
+        1 - x,
+        fun = "cdf",
+        decorators = c("CoreStatistics", "ExoticStatistics")
+      )
+    }
   )
 )
 
 
 #' @export
 as.data.table.PredictionSurv = function(x, ...) { # nolint
+
   tab = as.data.table(x$data[c("row_ids", "crank", "lp", "response")])
   tab$time = x$data$truth[, 1L]
   tab$status = as.logical(x$data$truth[, 2L])
   if ("distr" %in% x$predict_types) {
-    tab$distr = list(list(x$distr))
+    # annoyingly need this many lists to get nice printing
+    tab$distr = list(list(list(r6_private(x)$.distr())))
   }
   setcolorder(tab, c("row_ids", "time", "status"))[]
 }
